@@ -45,18 +45,20 @@ class Release:
             - download_url : (str) package download url
             - platform : (seq<str>) list of available platforms
             - keywords : (seq<str>) list of keywords
-            - licence : (str) the licence"""
+            - license : (str) the license"""
     name = 'PyTango'
-    version_info = (7, 1, 6, 'final', 0)
+    version_info = (7, 2, 4, 'final', 0)
     version = '.'.join(map(str, version_info[:3]))
     version_long = version + ''.join(map(str, version_info[3:]))
-    version_description = 'This version implements the C++ Tango 7.1 API.'
+    version_description = 'This version implements the C++ Tango 7.2 API.'
     version_number = int(version.replace('.',''))
     description = 'A python binding for the Tango control system'
     long_description = 'This module implements the Python Tango Device API mapping'
     license = 'LGPL'
     authors = { 'Coutinho' : ('Tiago Coutinho' , 'tcoutinho@cells.es') }
-    url = 'http://packages.python.org/PyTango'
+    author_lines = "\n".join([ "%s <%s>" % x for x in authors.values()])
+    url = 'http://www.tango-controls.org/static/PyTango/latest/doc/html/'
     download_url = 'http://pypi.python.org/packages/source/P/PyTango'
-    platform = ['Linux', 'Windows XP/2000/NT', 'Windows 95/98/ME']
+    platform = ['Linux', 'Windows XP/Vista/7']
     keywords = ['Tango', 'CORBA', 'binding']
+    
