@@ -1,11 +1,33 @@
+/*******************************************************************************
+
+   This file is part of PyTango, a python binding for Tango
+
+   http://www.tango-controls.org/static/PyTango/latest/doc/html/index.html
+
+   Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+   
+   PyTango is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
+   PyTango is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU Lesser General Public License for more details.
+  
+   You should have received a copy of the GNU Lesser General Public License
+   along with PyTango.  If not, see <http://www.gnu.org/licenses/>.
+   
+*******************************************************************************/
+
+#include "precompiled_header.hpp"
 #include "pytgutils.h"
 #include "exception.h"
 #include "server/device_class.h"
 #include "server/attr.h"
 #include "server/command.h"
 
-#include <sstream>
-
 using namespace boost::python;
 
 #define __AUX_DECL_CALL_DEVCLASS_METHOD \
@@ -150,10 +172,6 @@ CppDeviceClassWrap::~CppDeviceClassWrap()
 void CppDeviceClassWrap::init_class()
 {
     AutoPythonGIL python_guard;
-    
-    //@TODO remove this line when Tango C++ is cleaned up
-    //set_py_class(true);
-
     signal_handler_defined = is_method_defined(m_self, "signal_handler");
 }
 
@@ -162,12 +180,23 @@ void CppDeviceClassWrap::attribute_factory(std::vector<Tango::Attr *> &att_list)
     //
     // make sure we pass the same vector object to the python method
     //
+    AutoPythonGIL python_guard;
+
     object py_att_list(
                 handle<>(
                     to_python_indirect<
                         std::vector<Tango::Attr *>,
                         detail::make_reference_holder>()(att_list)));
-    CALL_DEVCLASS_METHOD_VARGS(_DeviceClass__attribute_factory, py_att_list)
+    try
+    {
+        boost::python::call_method<void>(m_self, "_DeviceClass__attribute_factory",
+                                         py_att_list);
+    }
+    catch(boost::python::error_already_set &eas)
+    {
+        handle_python_exception(eas);
+    }
+
 }
 
 void CppDeviceClassWrap::command_factory()
@@ -175,6 +204,29 @@ void CppDeviceClassWrap::command_factory()
     CALL_DEVCLASS_METHOD(_DeviceClass__command_factory)
 }
 
+void CppDeviceClassWrap::device_name_factory(std::vector<std::string> &dev_list)
+{
+    //
+    // make sure we pass the same vector object to the python method
+    //
+    AutoPythonGIL python_guard;
+
+    object py_dev_list(
+                handle<>(
+                    to_python_indirect<
+                        std::vector<std::string>,
+                        detail::make_reference_holder>()(dev_list)));
+    try
+    {
+        boost::python::call_method<void>(m_self, "device_name_factory",
+                                         py_dev_list);
+    }
+    catch(boost::python::error_already_set &eas)
+    {
+        handle_python_exception(eas);
+    }
+}
+
 void CppDeviceClassWrap::device_factory(const Tango::DevVarStringArray *dev_list)
 {
     CALL_DEVCLASS_METHOD_VARGS(device_factory, dev_list)
@@ -216,7 +268,6 @@ void CppDeviceClassWrap::delete_class()
     {
         handle_python_exception(eas);
     }
-
 }
 
 namespace PyDeviceClass
@@ -254,12 +305,13 @@ namespace PyDeviceClass
     void (*add_device1)(CppDeviceClass &, auto_ptr<Tango::DeviceImpl>) = &add_device;
     void (*add_device2)(CppDeviceClass &, auto_ptr<Tango::Device_4Impl>) = &add_device;
     */
+    
 }
 
 BOOST_PYTHON_MEMBER_FUNCTION_OVERLOADS (export_device_overload,
                                         CppDeviceClass::export_device, 1, 2)
 
-#if ((defined sun) || (defined WIN32))
+#if !(defined __linux)
 BOOST_PYTHON_MEMBER_FUNCTION_OVERLOADS (register_signal_overload,
                                         Tango::DeviceClass::register_signal, 1, 1)
 #else
@@ -283,6 +335,7 @@ void export_device_class()
         init<const std::string &>())
 
         .def("device_factory", &CppDeviceClassWrap::device_factory)
+        .def("device_name_factory", &CppDeviceClassWrap::device_name_factory)
         .def("export_device", &CppDeviceClass::export_device,
             export_device_overload())
         //.def("_add_device", PyDeviceClass::add_device1)
@@ -322,9 +375,10 @@ void export_device_class()
         .def("_device_destroyer",
             (void (Tango::DeviceClass::*) (const char *))
             &Tango::DeviceClass::device_destroyer)
-        .def("is_py_class", &Tango::DeviceClass::is_py_class)
         .def("_create_attribute", &CppDeviceClass::create_attribute)
         .def("_create_command", &CppDeviceClass::create_command)
+        .def("get_class_attr", &Tango::DeviceClass::get_class_attr,
+            return_value_policy<reference_existing_object>())
     ;
     implicitly_convertible<auto_ptr<CppDeviceClassWrap>, auto_ptr<CppDeviceClass> >();
 }
